@@ -1,4 +1,4 @@
-from ..providers import ModelProvider
+from ...providers import ModelProvider
 from ._provider_wrapper import ProviderLLMWrapper
 
 
@@ -8,5 +8,5 @@ class CohereLLM(ProviderLLMWrapper):
     """
 
     @classmethod
-    def model_type(cls) -> str:
+    def model_gateway(cls):
         return ModelProvider.COHERE
